@@ -1,4 +1,4 @@
-import warnings
+import sys
 from typing import Optional
 
 from AnyQt.QtCore import (
@@ -25,14 +25,7 @@ class ComboBox(QComboBox):
     Prefer to use this class in place of plain QComboBox when the used
     model will possibly contain many items.
     """
-    def __init__(self, parent=None, maximumContentsLength=-1, **kwargs):
-        if maximumContentsLength != -1:
-            warnings.warn(
-                f"'{__name__}.ComboBox.maximumContentsLength' is deprecated "
-                "and has no effect. It will be removed in orange-widget-base "
-                "4.6",
-                FutureWarning
-            )
+    def __init__(self, parent=None, **kwargs):
         self.__maximumContentsLength = MAXIMUM_CONTENTS_LENGTH
         super().__init__(parent, **kwargs)
 
@@ -245,6 +238,10 @@ class ComboBoxSearch(QComboBox):
         popuprect_origin = style.subControlRect(
             QStyle.CC_ComboBox, opt, QStyle.SC_ComboBoxListBoxPopup, self
         )  # type: QRect
+        if sys.platform == "darwin":
+            slmargin = self.__searchline.style() \
+                .pixelMetric(QStyle.PM_FocusFrameVMargin)
+            popuprect_origin.adjust(slmargin / 2, 0, -slmargin * 1.5, slmargin)
         popuprect_origin = QRect(
             self.mapToGlobal(popuprect_origin.topLeft()),
             popuprect_origin.size()
