@@ -29,7 +29,7 @@ from orangewidget.utils.messages import (
     WidgetMessagesMixin, UnboundMsg, MessagesWidget
 )
 from orangewidget.utils.signals import (
-    WidgetSignalsMixin, Input, Output, AttributeList,
+    WidgetSignalsMixin, Input, Output, MultiInput,
     InputSignal, OutputSignal,
     Default, NonDefault, Single, Multiple, Dynamic, Explicit
 )  # pylint: disable=unused-import
@@ -42,8 +42,8 @@ Msg = UnboundMsg
 
 
 __all__ = [
-    "OWBaseWidget", "Input", "Output", "AttributeList", "Message", "Msg",
-    "StateInfo",
+    "OWBaseWidget", "Input", "Output", "MultiInput",
+    "Message", "Msg", "StateInfo",
 ]
 
 
@@ -254,9 +254,6 @@ class OWBaseWidget(QDialog, OWComponent, Report, ProgressBarMixin,
     # Private Interface
     # -------------------------------------------------------------------------
 
-    # Global widget count
-    widget_id = 0
-
     # Custom widget id, kept for backward compatibility
     id = None
 
@@ -307,9 +304,6 @@ class OWBaseWidget(QDialog, OWComponent, Report, ProgressBarMixin,
         self.graphButton = None
         self.report_button = None
 
-        OWBaseWidget.widget_id += 1
-        self.widget_id = OWBaseWidget.widget_id
-
         captionTitle = self.name if captionTitle is None else captionTitle
 
         # must be set without invoking setCaption
@@ -343,6 +337,7 @@ class OWBaseWidget(QDialog, OWComponent, Report, ProgressBarMixin,
         self.__splitter = None
         if self.want_basic_layout:
             self.set_basic_layout()
+            self.update_summaries()
 
         sc = QShortcut(QKeySequence(Qt.ShiftModifier | Qt.Key_F1), self)
         sc.activated.connect(self.__quicktip)
@@ -480,7 +475,7 @@ class OWBaseWidget(QDialog, OWComponent, Report, ProgressBarMixin,
         self.layout().addWidget(self.__splitter)
 
     def _insert_control_area(self):
-        self.left_side = gui.vBox(self.__splitter, addSpace=0, spacing=0)
+        self.left_side = gui.vBox(self.__splitter, spacing=0)
         if self.want_main_area:
             self.left_side.setSizePolicy(
                 QSizePolicy.MinimumExpanding, QSizePolicy.MinimumExpanding)
@@ -515,7 +510,7 @@ class OWBaseWidget(QDialog, OWComponent, Report, ProgressBarMixin,
         if not self.want_main_area:
             gui.separator(self.left_side)
         self.buttonsArea = gui.widgetBox(
-            self.left_side, addSpace=0, spacing=6,
+            self.left_side, spacing=6,
             orientation=self.buttons_area_orientation,
             sizePolicy=(QSizePolicy.MinimumExpanding,
                         QSizePolicy.Maximum)
@@ -972,7 +967,8 @@ class OWBaseWidget(QDialog, OWComponent, Report, ProgressBarMixin,
             self.savedWidgetGeometry = bytes(self.saveGeometry())
 
     def sizeHint(self):
-        if self.mainArea_width_height_ratio is None:
+        if not self.want_basic_layout \
+                or self.mainArea_width_height_ratio is None:
             return super().sizeHint()
 
         # Super sizeHint with scroll_area isn't calculated right (slightly too small on macOS)
